Learn R Programming

spRingsteen (version 0.1.0)

songs: Data for all songs in the spRingsteen dataset.

Description

Data describing all songs which have been played by Bruce Springsteen both solo and with numerous bands from the year 1973 to present day. Can be joined with setlists using song_key.

Usage

songs

Arguments

Format

A data frame with 4 variables:

song_key

Primary key of the data frame.

title

Title of the song.

lyrics

Lyrics of the song if available in the database.

album

Name of the album on which the song appears if available in the database.

Examples

Run this code
library(dplyr)
# What are the most common albums?

songs %>%
  filter(!is.na(album)) %>%
  count(album, sort = TRUE)

# What word occurs most frequently in the lyrics from the album 'Born To Run'
library(tidytext)

songs %>%
 filter(album == 'Born To Run') %>%
 select(title, lyrics) %>%
 unnest_tokens(word, lyrics) %>%
 count(word, sort = TRUE) %>%
 anti_join(stop_words, by = 'word')

Run the code above in your browser using DataLab